package com.ibm.sat.wasce;

import java.io.File;
import java.io.FileInputStream;
import java.util.Properties;

import com.ibm.jsdt.support.SupportBase;
import com.ibm.jsdt.support.SupportHelper;

public class WasceLinuxPDC extends SupportBase {

	private Properties wasceProperties = null;
	private File wascePropertiesFile = null;
	private int RC = 0;
	
	/**
	 * Return the constant SUCCESS, FAILURE, or PDC_EXISTS to indicate if WASCE 
	 * is installed.
	 *
	 * @return SUCCESS, FAILURE, or PDC_EXISTS. 
	 */	
	private int execute() {

		String statusMessage = null;
		
		SupportHelper helper = new SupportHelper();
		if (isWasceInstalled(helper)) {
			if (getVersion(helper).equals("1.1.0.1")) {
				RC = PDC_EXISTS;
				statusMessage = "WebSphere Application Server Community Edition 1.1.0.1 is already installed.  Deployment successful";
			}
			else {
				RC = FAILURE;
				statusMessage = "A different version of WebSphere Application Server Community Edition is already installed.  Installation aborting";
			}
		}
		else {
			RC = SUCCESS;
			statusMessage = "OK to install WebSphere Application Server Community Edition 1.1.0.1.";
		}			
		
		helper.log(statusMessage);
		return RC;
	}
	
	/**
	 * Return a boolean to indicate whether WASCE is installed. 
	 * 
	 * @param myHelper
	 * @return
	 */
	private boolean isWasceInstalled(SupportHelper myHelper) {

		return (getWasceProperties(myHelper)!= null);
	}
	
	/**
	 * Return a Properties instance for the WASCE _version.properties file or
	 * null if the file does not exist.
	 * 
	 * @param myHelper
	 * @return an instance of Properties
	 */
	private Properties getWasceProperties(SupportHelper myHelper) {
		
		if (wasceProperties == null) {
			File myPropFile = getWascePropertiesFile(myHelper);
			if (myPropFile.exists()) {
				wasceProperties = new Properties();
				try {
					FileInputStream fis = new FileInputStream(myPropFile);
					wasceProperties.load(fis);
					fis.close();
			    }
				catch (Exception e) {
					myHelper.log(e.toString());
				}
			}
		}
		return wasceProperties;
	}
	
	/**
	 * Return a File instance for the WASCE _version.properties file.  Use the 
	 * value of the shared variable that matches the current operating system 
	 * to determine the path to WASCE HOME.  
	 * 
	 * @param myHelper
	 * @return instance of File
	 */
	private File getWascePropertiesFile(SupportHelper myHelper) {
		if (wascePropertiesFile == null) {
			String variableName = "installLocation";  
			String wasceHome = myHelper.getIbmNsiPropValue(variableName);
			wascePropertiesFile = new File(wasceHome + "/_version.properties");			
		}
		return wascePropertiesFile;
	}

	private String getVersion(SupportHelper myHelper) {
		
		String version = "";
		
		Properties myProperties = getWasceProperties(myHelper);
		if (myProperties != null) {
			version = myProperties.getProperty("version");
		}
		return version.trim();
	}
	
	/**
	 * Perform a Pre-Deployment Check to see if WebSphere Application Server 
	 * Community Edition is installed.  If it is not abort installation of the
	 * MidWest Trucking Application.
	 * 
	 * @param args
	 */
	public static void main(String[] args) {

		WasceLinuxPDC preDeploymentChecker = new WasceLinuxPDC();
		System.exit(preDeploymentChecker.execute());
	}

}
